import type {
  CreateSocialMutation,
  CreateSocialInput,
  CreateSocialMutationVariables,
} from 'types/graphql'

import { navigate, routes } from '@redwoodjs/router'
import { useMutation } from '@redwoodjs/web'
import type { TypedDocumentNode } from '@redwoodjs/web'
import { toast } from '@redwoodjs/web/toast'

import SocialForm from 'src/components/Social/SocialForm'

const CREATE_SOCIAL_MUTATION: TypedDocumentNode<
  CreateSocialMutation,
  CreateSocialMutationVariables
> = gql`
  mutation CreateSocialMutation($input: CreateSocialInput!) {
    createSocial(input: $input) {
      id
    }
  }
`

const NewSocial = () => {
  const [createSocial, { loading, error }] = useMutation(
    CREATE_SOCIAL_MUTATION,
    {
      onCompleted: () => {
        toast.success('Social created')
        navigate(routes.socials())
      },
      onError: (error) => toast.error(error.message),
    }
  )

  const onSave = (input: CreateSocialInput) =>
    createSocial({ variables: { input } })

  return (
    <div className="flex w-full justify-center">
      <div className="overflow-hidden overflow-x-auto rounded-xl bg-base-100">
        <table className="table w-80">
          <thead className="bg-base-200 font-syne">
            <tr>
              <th>New Social</th>
            </tr>
          </thead>
          <tbody>
            <tr>
              <th>
                <SocialForm onSave={onSave} error={error} loading={loading} />
              </th>
            </tr>
          </tbody>
        </table>
      </div>
    </div>
  )
}

export default NewSocial
